@@ -50,7 +50,7 @@
 #include "gdal.h"
 #include "gdal_priv.h"
 
-CPL_CVSID("$Id: rawdataset.cpp 37414 2017-02-18 12:13:26Z goatbar $");
+CPL_CVSID("$Id: rawdataset.cpp 40082 2017-09-12 13:58:48Z rouault $");
 
 /************************************************************************/
 /*                           RawRasterBand()                            */
@@ -1160,9 +1160,10 @@ CPLErr RawDataset::IRasterIO( GDALRWFlag eRWFlag,
         int iBandIndex = 0;
         for( ; iBandIndex < nBandCount; iBandIndex++ )
         {
-            RawRasterBand *poBand = static_cast<RawRasterBand *>(
+            RawRasterBand *poBand = dynamic_cast<RawRasterBand *>(
                 GetRasterBand(panBandMap[iBandIndex]));
-            if( !poBand->CanUseDirectIO(nXOff, nYOff,
+            if( poBand == NULL ||
+                !poBand->CanUseDirectIO(nXOff, nYOff,
                                         nXSize, nYSize, eBufType) )
             {
                 break;
