@@ -32,7 +32,7 @@
 
 #include "webp_headers.h"
 
-CPL_CVSID("$Id: webpdataset.cpp 37788 2017-03-19 11:52:40Z rouault $");
+CPL_CVSID("$Id: webpdataset.cpp 38837 2017-06-03 12:33:56Z rouault $");
 
 /************************************************************************/
 /* ==================================================================== */
@@ -283,6 +283,15 @@ CPLErr WEBPDataset::Uncompress()
     bHasBeenUncompressed = TRUE;
     eUncompressErrRet = CE_Failure;
 
+    // To avoid excessive memory allocation attempts
+    // Normally WebP images are no larger than 16383x16383*4 ~= 1 GB
+    if( nRasterXSize > INT_MAX / (nRasterYSize * nBands) )
+    {
+        CPLError(CE_Failure, CPLE_NotSupported,
+                 "Too large image");
+        return CE_Failure;
+    }
+
     pabyUncompressed = reinterpret_cast<GByte*>(
         VSIMalloc3(nRasterXSize, nRasterYSize, nBands ) );
     if (pabyUncompressed == NULL)
