@@ -34,7 +34,7 @@
 #include <algorithm>
 #include <vector>
 
-CPL_CVSID("$Id: xyzdataset.cpp 36822 2016-12-12 11:18:45Z rouault $");
+CPL_CVSID("$Id: xyzdataset.cpp 39396 2017-06-30 09:23:09Z rouault $");
 
 static const double RELATIVE_ERROR = 1e-3;
 
@@ -64,6 +64,7 @@ class XYZDataset : public GDALPamDataset
     int         bSameNumberOfValuesPerLine;
     double      dfMinZ;
     double      dfMaxZ;
+    bool        bEOF;
 
     static int          IdentifyEx( GDALOpenInfo *, int&, int& nCommentLineCount );
 
@@ -149,11 +150,16 @@ CPLErr XYZRasterBand::IReadBlock( CPL_UNUSED int nBlockXOff,
     {
         poGDS->nDataLineNum = 0;
         poGDS->nLineNum = 0;
+        poGDS->bEOF = false;
         VSIFSeekL(poGDS->fp, 0, SEEK_SET);
 
         for(int i=0;i<poGDS->nCommentLineCount;i++)
         {
-            CPLReadLine2L(poGDS->fp, 100, NULL);
+            if( CPLReadLine2L(poGDS->fp, 100, NULL) == NULL )
+            {
+                poGDS->bEOF = true;
+                return CE_Failure;
+            }
             poGDS->nLineNum ++;
         }
 
@@ -161,12 +167,15 @@ CPLErr XYZRasterBand::IReadBlock( CPL_UNUSED int nBlockXOff,
         {
             const char* pszLine = CPLReadLine2L(poGDS->fp, 100, NULL);
             if (pszLine == NULL)
+            {
+                poGDS->bEOF = true;
                 return CE_Failure;
+            }
             poGDS->nLineNum ++;
         }
     }
 
-    if( !poGDS->bSameNumberOfValuesPerLine && nBlockYOff != nLastYOff + 1 )
+    if( !poGDS->bSameNumberOfValuesPerLine )
     {
         if( nBlockYOff < nLastYOff )
         {
@@ -179,6 +188,10 @@ CPLErr XYZRasterBand::IReadBlock( CPL_UNUSED int nBlockXOff,
         }
         else
         {
+            if( poGDS->bEOF )
+            {
+                return CE_Failure;
+            }
             for( int iY = nLastYOff + 1; iY < nBlockYOff; iY++ )
             {
                 if( IReadBlock(0, iY, NULL) != CE_None )
@@ -186,13 +199,20 @@ CPLErr XYZRasterBand::IReadBlock( CPL_UNUSED int nBlockXOff,
             }
         }
     }
-    else if( poGDS->bSameNumberOfValuesPerLine )
+    else
     {
+        if( poGDS->bEOF )
+        {
+            return CE_Failure;
+        }
         while(poGDS->nDataLineNum < nLineInFile)
         {
             const char* pszLine = CPLReadLine2L(poGDS->fp, 100, NULL);
             if (pszLine == NULL)
+            {
+                poGDS->bEOF = true;
                 return CE_Failure;
+            }
             poGDS->nLineNum ++;
 
             const char* pszPtr = pszLine;
@@ -242,6 +262,7 @@ CPLErr XYZRasterBand::IReadBlock( CPL_UNUSED int nBlockXOff,
             const char* pszLine = CPLReadLine2L(poGDS->fp, 100, NULL);
             if (pszLine == NULL)
             {
+                poGDS->bEOF = true;
                 if( poGDS->bSameNumberOfValuesPerLine )
                 {
                     CPLError(CE_Failure, CPLE_AppDefined,
@@ -453,7 +474,8 @@ XYZDataset::XYZDataset() :
     nDataLineNum(GINTBIG_MAX),
     bSameNumberOfValuesPerLine(TRUE),
     dfMinZ(0),
-    dfMaxZ(0)
+    dfMaxZ(0),
+    bEOF(false)
 {
     adfGeoTransform[0] = 0;
     adfGeoTransform[1] = 1;
@@ -662,7 +684,13 @@ GDALDataset *XYZDataset::Open( GDALOpenInfo * poOpenInfo )
     int nMinTokens = 0;
 
     for( int i = 0; i < nCommentLineCount; i++ )
-        CPLReadLine2L(fp, 100, NULL);
+    {
+        if( CPLReadLine2L(fp, 100, NULL) == NULL )
+        {
+            VSIFCloseL(fp);
+            return NULL;
+        }
+    }
 
 /* -------------------------------------------------------------------- */
 /*      Parse header line                                               */
@@ -802,6 +830,7 @@ GDALDataset *XYZDataset::Open( GDALOpenInfo * poOpenInfo )
         }
 
         char chLocalDecimalSep = chDecimalSep ? chDecimalSep : '.';
+        int nUsefulColsFound = 0;
         while((ch = *pszPtr) != '\0')
         {
             if (ch == ' ')
@@ -820,11 +849,18 @@ GDALDataset *XYZDataset::Open( GDALOpenInfo * poOpenInfo )
                 if (bLastWasSep)
                 {
                     if (nCol == nXIndex)
+                    {
+                        nUsefulColsFound ++;
                         dfX = CPLAtofDelim(pszPtr, chLocalDecimalSep);
+                    }
                     else if (nCol == nYIndex)
+                    {
+                        nUsefulColsFound ++;
                         dfY = CPLAtofDelim(pszPtr, chLocalDecimalSep);
+                    }
                     else if (nCol == nZIndex)
                     {
+                        nUsefulColsFound ++;
                         dfZ = CPLAtofDelim(pszPtr, chLocalDecimalSep);
                         if( nDataLineNum == 0 )
                         {
@@ -881,6 +917,14 @@ GDALDataset *XYZDataset::Open( GDALOpenInfo * poOpenInfo )
             VSIFCloseL(fp);
             return NULL;
         }
+        if( nUsefulColsFound != 3 )
+        {
+            CPLError(CE_Failure, CPLE_AppDefined,
+                     "At line " CPL_FRMT_GIB ", did not find X, Y and/or Z values",
+                      nLineNum);
+            VSIFCloseL(fp);
+            return NULL;
+        }
 
         if (nDataLineNum == 1)
         {
@@ -930,6 +974,7 @@ GDALDataset *XYZDataset::Open( GDALOpenInfo * poOpenInfo )
                                  fabs(*oIter - static_cast<int>(*oIter / dfStepX + 0.5) * dfStepX) / dfStepX < RELATIVE_ERROR )
                         {
                             nCountStepX = -1; // disable update of mean
+                            ++ oIter;
                         }
                         else if( dfStepX > *oIter &&
                                  fabs(dfStepX - static_cast<int>(dfStepX / *oIter + 0.5) * (*oIter)) / dfStepX < RELATIVE_ERROR )
