@@ -30,7 +30,7 @@
 
 #include <algorithm>
 
-CPL_CVSID("$Id: dgnread.cpp 37472 2017-02-26 02:47:45Z goatbar $");
+CPL_CVSID("$Id: dgnread.cpp 38747 2017-05-31 22:12:52Z rouault $");
 
 static DGNElemCore *DGNParseTCB( DGNInfo * );
 static DGNElemCore *DGNParseColorTable( DGNInfo * );
@@ -465,7 +465,8 @@ static DGNElemCore *DGNProcessElement( DGNInfo *psDGN, int nType, int nLevel )
               psLine->vertices[1].z = DGN_INT32( psDGN->abyElem + 56 );
           }
 
-          if (deltaStart && deltaLength)
+          if (deltaStart && deltaLength &&
+              deltaStart + 1 * 4 + 2 + 2 <= psLine->core.attr_bytes)
           {
               for (int i=0; i<2; i++)
               {
@@ -542,7 +543,8 @@ static DGNElemCore *DGNProcessElement( DGNInfo *psDGN, int nType, int nLevel )
               if( psDGN->dimension == 3 )
                   psLine->vertices[i].z =
                       DGN_INT32( psDGN->abyElem + 46 + i*pntsize );
-              if (deltaStart && deltaLength)
+              if (deltaStart && deltaLength &&
+                  deltaStart + i * 4 + 2 + 2 <= psLine->core.attr_bytes)
               {
                 int dx = DGN_INT16(psLine->core.attr_data + deltaStart + i * 4);
                 int dy = DGN_INT16(psLine->core.attr_data + deltaStart + i * 4 + 2);
@@ -1023,7 +1025,8 @@ static DGNElemCore *DGNProcessElement( DGNInfo *psDGN, int nType, int nLevel )
             psBounds->vertices[i].x = DGN_INT32( psDGN->abyElem + 40 + i*8 );
             psBounds->vertices[i].y = DGN_INT32( psDGN->abyElem + 44 + i*8 );
             psBounds->vertices[i].z = 0;
-            if (deltaStart && deltaLength)
+            if (deltaStart && deltaLength &&
+                deltaStart + i * 4 + 2 + 2 <= psBounds->core.attr_bytes)
             {
                 int dx = DGN_INT16(psBounds->core.attr_data + deltaStart + i * 4);
                 int dy = DGN_INT16(psBounds->core.attr_data + deltaStart + i * 4 + 2);
