@@ -32,7 +32,7 @@
 #include "ogr_georss.h"
 #include "ogr_p.h"
 
-CPL_CVSID("$Id: ogrgeorsslayer.cpp 37371 2017-02-13 11:41:59Z rouault $");
+CPL_CVSID("$Id: ogrgeorsslayer.cpp 40552 2017-10-25 19:59:16Z rouault $");
 
 static const char* const apszAllowedATOMFieldNamesWithSubElements[] =
     { "author", "contributor", NULL };
@@ -605,9 +605,7 @@ void OGRGeoRSSLayer::endElementCbk(const char *pszName)
     if( pszColon )
         pszNoNSName = pszColon + 1;
 
-    if ((eFormat == GEORSS_ATOM && currentDepth == 1 && strcmp(pszNoNSName, "entry") == 0) ||
-        ((eFormat == GEORSS_RSS || eFormat == GEORSS_RSS_RDF) &&
-         (currentDepth == 1 || currentDepth == 2) && strcmp(pszNoNSName, "item") == 0))
+    if( bInFeature && currentDepth == featureDepth )
     {
         bInFeature = false;
         bInTagWithSubTag = false;
@@ -1801,28 +1799,6 @@ void OGRGeoRSSLayer::LoadSchema()
     VSIFSeekL( fpGeoRSS, 0, SEEK_SET );
 }
 
-/************************************************************************/
-/*                         OGRGeoRSSIsInt()                             */
-/************************************************************************/
-
-static int OGRGeoRSSIsInt(const char* pszStr)
-{
-    while(*pszStr == ' ')
-        pszStr++;
-
-    for( int i=0; pszStr[i]; i++ )
-    {
-        if (pszStr[i] == '+' || pszStr[i] == '-')
-        {
-            if (i != 0)
-                return FALSE;
-        }
-        else if (!(pszStr[i] >= '0' && pszStr[i] <= '9'))
-            return FALSE;
-    }
-    return TRUE;
-}
-
 /************************************************************************/
 /*                  startElementLoadSchemaCbk()                         */
 /************************************************************************/
@@ -1975,21 +1951,12 @@ void OGRGeoRSSLayer::startElementLoadSchemaCbk(const char *pszName, const char *
             if (currentAttrFieldDefn->GetType() == OFTInteger ||
                 currentAttrFieldDefn->GetType() == OFTReal)
             {
-                char* pszRemainingStr = NULL;
-                CPLStrtod(ppszAttr[i + 1], &pszRemainingStr);
-                if (pszRemainingStr == NULL ||
-                    *pszRemainingStr == 0 ||
-                    *pszRemainingStr == ' ')
+                const CPLValueType eType = CPLGetValueType(ppszAttr[i+1]);
+                if( eType == CPL_VALUE_REAL )
                 {
-                    if (currentAttrFieldDefn->GetType() == OFTInteger)
-                    {
-                        if( !OGRGeoRSSIsInt(ppszAttr[i + 1]) )
-                        {
-                            currentAttrFieldDefn->SetType(OFTReal);
-                        }
-                    }
+                    currentAttrFieldDefn->SetType(OFTReal);
                 }
-                else
+                else if( eType == CPL_VALUE_STRING )
                 {
                     currentAttrFieldDefn->SetType(OFTString);
                 }
@@ -2148,25 +2115,16 @@ void OGRGeoRSSLayer::endElementLoadSchemaCbk(const char *pszName)
             if (currentFieldDefn->GetType() == OFTInteger ||
                 currentFieldDefn->GetType() == OFTReal)
             {
-                char* pszRemainingStr = NULL;
-                CPLStrtod(pszSubElementValue, &pszRemainingStr);
-                if (pszRemainingStr == NULL ||
-                    *pszRemainingStr == 0 ||
-                    *pszRemainingStr == ' ')
+                const CPLValueType eType = CPLGetValueType(pszSubElementValue);
+                if( eType == CPL_VALUE_REAL )
                 {
-                    if (currentFieldDefn->GetType() == OFTInteger)
-                    {
-                        if( !OGRGeoRSSIsInt(pszSubElementValue) )
-                        {
-                            currentFieldDefn->SetType(OFTReal);
-                        }
-                    }
+                    currentFieldDefn->SetType(OFTReal);
                 }
-                else
+                else if( eType == CPL_VALUE_STRING )
                 {
                     currentFieldDefn->SetType(OFTString);
                 }
-            }
+             }
         }
 
         CPLFree(pszSubElementName);
