@@ -43,7 +43,7 @@
 #include "ogr_p.h"
 #include "ogr_spatialref.h"
 
-CPL_CVSID("$Id: gmlutils.cpp 37914 2017-04-06 17:38:46Z rouault $");
+CPL_CVSID("$Id: gmlutils.cpp 40033 2017-09-08 07:33:53Z rouault $");
 
 /************************************************************************/
 /*                GML_ExtractSrsNameFromGeometry()                      */
@@ -100,6 +100,12 @@ bool GML_IsSRSLatLongOrder(const char *pszSRSName)
         // Shortcut.
         return true;
     }
+    /* fguuid:jgd20??.bl (Japanese FGD GML v4) */
+    else if( EQUALN(pszSRSName, "fguuid:jgd2011.bl", 17) ||
+            EQUALN(pszSRSName, "fguuid:jgd2001.bl", 17) )
+    {
+        return true;
+    }
     else if( !EQUALN(pszSRSName, "EPSG:", 5) )
     {
         OGRSpatialReference oSRS;
@@ -108,13 +114,7 @@ bool GML_IsSRSLatLongOrder(const char *pszSRSName)
             if(oSRS.EPSGTreatsAsLatLong() || oSRS.EPSGTreatsAsNorthingEasting())
                 return true;
         }
-        return false;
     }
-    /* fguuid:jgd20??.bl (Japanese FGD GML v4) */
-    else if (strncmp(pszSRSName, "fguuid:jgd", 10) == 0 && strstr(pszSRSName, ".bl") != NULL) {
-        return true;
-    }
-
     return false;
 }
 
