@@ -36,7 +36,7 @@
 
 #include <algorithm>
 
-CPL_CVSID("$Id: ogrgmlasdatasource.cpp 38073 2017-04-20 17:00:47Z rouault $");
+CPL_CVSID("$Id: ogrgmlasdatasource.cpp 39652 2017-07-24 17:32:40Z rouault $");
 
 /************************************************************************/
 /*                          OGRGMLASDataSource()                        */
@@ -300,6 +300,7 @@ class GMLASTopElementParser : public DefaultHandler
             int         m_nStartElementCounter;
             bool        m_bFinish;
             bool        m_bFoundSWE;
+            std::map<CPLString,CPLString> m_oMapDocNSURIToPrefix;
 
     public:
                         GMLASTopElementParser();
@@ -311,6 +312,8 @@ class GMLASTopElementParser : public DefaultHandler
         const std::vector<PairURIFilename>& GetXSDs() const
                                             { return m_aoFilenames; }
         bool GetSWE() const { return m_bFoundSWE; }
+        const std::map<CPLString,CPLString>& GetMapDocNSURIToPrefix() const
+                                            { return m_oMapDocNSURIToPrefix; }
 
         virtual void startElement(
             const   XMLCh* const    uri,
@@ -435,6 +438,15 @@ void GMLASTopElementParser::startElement(
             CPLDebug("GMLAS", "SWE namespace found");
             m_bFoundSWE = true;
         }
+        else if( osAttrURIPrefix == szXMLNS_URI && !osAttrValue.empty() &&
+                 !osAttrLocalname.empty() )
+        {
+#ifdef DEBUG_VERBOSE
+            CPLDebug("GMLAS", "Namespace %s = %s",
+                     osAttrLocalname.c_str(), osAttrValue.c_str() );
+#endif
+            m_oMapDocNSURIToPrefix[ osAttrValue ] = osAttrLocalname;
+        }
     }
 
     if( m_nStartElementCounter == 1 )
@@ -807,6 +819,8 @@ bool OGRGMLASDataSource::Open(GDALOpenInfo* poOpenInfo)
         {
             m_bFoundSWE = true;
         }
+        oAnalyzer.SetMapDocNSURIToPrefix(
+                                    topElementParser.GetMapDocNSURIToPrefix());
     }
     std::vector<PairURIFilename> aoXSDs;
     if( osXSDFilenames.empty() )
