@@ -49,7 +49,7 @@
 #include "ogr_feature.h"
 #include "ogr_geometry.h"
 
-CPL_CVSID("$Id: mitab_feature_mif.cpp 37371 2017-02-13 11:41:59Z rouault $");
+CPL_CVSID("$Id: mitab_feature_mif.cpp 39591 2017-07-15 15:08:47Z rouault $");
 
 /*=====================================================================
  *                      class TABFeature
@@ -1602,6 +1602,14 @@ int TABArc::ReadGeometryFromMIFFile(MIDDATAFile *fp)
     CSLDestroy(papszToken);
     papszToken = NULL;
 
+    if( fabs(m_dEndAngle - m_dStartAngle) >= 721 )
+    {
+        CPLError(CE_Failure, CPLE_AppDefined,
+                 "Wrong start and end angles: %f %f",
+                 m_dStartAngle, m_dEndAngle);
+        return -1;
+    }
+
     /*-------------------------------------------------------------
      * Start/End angles
      * Since the angles are specified for integer coordinates, and
@@ -2203,7 +2211,10 @@ int TABCollection::ReadGeometryFromMIFFile(MIDDATAFile *fp)
             pszLine++;  // skip leading spaces
 
         if (*pszLine == '\0')
+        {
+            pszLine = fp->GetLine();
             continue;  // Skip blank lines
+        }
 
         if (STARTS_WITH_CI(pszLine, "REGION"))
         {
