@@ -51,7 +51,7 @@
 #include "ogr_spatialref.h"
 #include "ogrsf_frmts.h"
 
-CPL_CVSID("$Id: mitab_miffile.cpp 37458 2017-02-25 18:58:53Z rouault $");
+CPL_CVSID("$Id: mitab_miffile.cpp 38321 2017-05-14 11:12:47Z rouault $");
 
 /*=====================================================================
  *                      class MIFFile
@@ -433,19 +433,23 @@ int MIFFile::ParseMIFHeader(int* pbIsEmpty)
            }
           CSLDestroy(papszToken);
         }
-        else if (STARTS_WITH_CI(pszLine, "UNIQUE"))
+        else if (m_pszUnique == NULL &&
+                 STARTS_WITH_CI(pszLine, "UNIQUE"))
         {
             bColumns = FALSE; bCoordSys = FALSE;
 
             m_pszUnique = CPLStrdup(pszLine + 6);
         }
-        else if (STARTS_WITH_CI(pszLine, "INDEX"))
+        else if (m_pszIndex == NULL &&
+                 STARTS_WITH_CI(pszLine, "INDEX"))
         {
             bColumns = FALSE; bCoordSys = FALSE;
 
             m_pszIndex = CPLStrdup(pszLine + 5);
         }
-        else if (STARTS_WITH_CI(pszLine, "COORDSYS") )
+        else if (m_pszCoordSys == NULL &&
+                 STARTS_WITH_CI(pszLine, "COORDSYS") &&
+                 CPLStrnlen(pszLine, 9) >= 9)
         {
             bCoordSys = TRUE;
             m_pszCoordSys = CPLStrdup(pszLine + 9);
@@ -1062,6 +1066,9 @@ int MIFFile::Close()
     CPLFree(m_pszDelimiter);
     m_pszDelimiter = NULL;
 
+    CPLFree(m_pszUnique);
+    m_pszUnique = NULL;
+
     CPLFree(m_pszFname);
     m_pszFname = NULL;
 
