@@ -32,7 +32,7 @@
 #include "ntf.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ntf_estlayers.cpp 35911 2016-10-24 15:03:26Z goatbar $");
+CPL_CVSID("$Id: ntf_estlayers.cpp 39029 2017-06-09 14:40:19Z rouault $");
 
 static const int MAX_LINK = 5000;
 
@@ -1435,7 +1435,7 @@ static OGRFeature *TranslateProfilePoint( NTFFileReader *poReader,
                                     NULL );
 
     // Set HEIGHT/elevation
-    OGRPoint    *poPoint = (OGRPoint *) poFeature->GetGeometryRef();
+    OGRPoint    *poPoint = dynamic_cast<OGRPoint *>(poFeature->GetGeometryRef());
 
     if( poPoint != NULL && poPoint->getCoordinateDimension() == 3 )
     {
@@ -1482,7 +1482,7 @@ static OGRFeature *TranslateProfileLine( NTFFileReader *poReader,
                                     NULL );
 
     // Set HEIGHT/elevation
-    OGRLineString *poLine = (OGRLineString *) poFeature->GetGeometryRef();
+    OGRLineString *poLine = dynamic_cast<OGRLineString*>(poFeature->GetGeometryRef());
 
     poFeature->SetField( 2, poFeature->GetFieldAsDouble(2) * 0.01 );
     if( poLine != NULL && poLine->getCoordinateDimension() == 2 )
@@ -1743,9 +1743,10 @@ void NTFFileReader::EstablishLayer( const char * pszLayerName,
                 {
                     oFieldDefn.SetType( OFTReal );
                     oFieldDefn.SetWidth( poClass->panAttrMaxWidth[iGAtt]+1 );
-                    if( pszFormat[2] == ',' )
+                    const size_t nFormatLen = strlen(pszFormat);
+                    if( nFormatLen >= 4 && pszFormat[2] == ',' )
                         oFieldDefn.SetPrecision(atoi(pszFormat+3));
-                    else if( pszFormat[3] == ',' )
+                    else if( nFormatLen >= 5 && pszFormat[3] == ',' )
                         oFieldDefn.SetPrecision(atoi(pszFormat+4));
                 }
 
