@@ -30,7 +30,7 @@
 #include "ogr_oci.h"
 #include "cpl_conv.h"
 
-CPL_CVSID("$Id: ogrocisession.cpp 38061 2017-04-19 05:23:56Z ilucena $");
+CPL_CVSID("$Id: ogrocisession.cpp 40697 2017-11-13 13:26:12Z rouault $");
 
 /************************************************************************/
 /*                          OGRGetOCISession()                          */
@@ -141,16 +141,13 @@ int OGROCISession::EstablishSession( const char *pszUseridIn,
 /*      Initialize Environment handler                                  */
 /* -------------------------------------------------------------------- */
 
-    if( Failed( OCIInitialize((ub4) (OCI_DEFAULT | OCI_OBJECT), (dvoid *)0,
-                (dvoid * (*)(dvoid *, size_t)) 0,
-                (dvoid * (*)(dvoid *, dvoid *, size_t))0,
-                (void (*)(dvoid *, dvoid *)) 0 ) ) )
-    {
-        return FALSE;
-    }
-
-    if( Failed( OCIEnvInit( (OCIEnv **) &hEnv, OCI_DEFAULT, (size_t) 0,
-                (dvoid **) 0 ) ) )
+    if( Failed( OCIEnvCreate( (OCIEnv **) &hEnv, OCI_THREADED | OCI_OBJECT,
+                              NULL,
+                              NULL,
+                              NULL,
+                              NULL,
+                              0,
+                              NULL ) ) )
     {
         return FALSE;
     }
@@ -324,7 +321,7 @@ int OGROCISession::EstablishSession( const char *pszUseridIn,
         nMaxNameLength = 128;
     }
 
-    CPLFree( papszNameValue );
+    CSLDestroy( papszNameValue );
 
 /* -------------------------------------------------------------------- */
 /*      Setting up the OGR compatible time formatting rules.            */
