@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: ogr_plscenes.h 37271 2017-02-02 13:34:26Z rouault $
+ * $Id: ogr_plscenes.h 39215 2017-06-20 19:09:46Z rouault $
  *
  * Project:  PlanetLabs scene driver
  * Purpose:  PLScenes driver interface
@@ -41,102 +41,6 @@
 #include <set>
 #include <vector>
 
-class OGRPLScenesLayer;
-
-class OGRPLScenesDataset: public GDALDataset
-{
-        bool            bMustCleanPersistent;
-        CPLString       osBaseURL;
-        CPLString       osAPIKey;
-
-        int             nLayers;
-        OGRPLScenesLayer  **papoLayers;
-        std::map<OGRLayer*, OGRPLScenesLayer*> oMapResultSetToSourceLayer;
-
-        char             **GetBaseHTTPOptions();
-        GDALDataset       *OpenRasterScene(GDALOpenInfo* poOpenInfo,
-                                           CPLString osScene,
-                                           char** papszOptions);
-
-    public:
-                            OGRPLScenesDataset();
-                           virtual ~OGRPLScenesDataset();
-
-        virtual int         GetLayerCount() override { return nLayers; }
-        virtual OGRLayer   *GetLayer(int idx) override;
-        virtual OGRLayer   *GetLayerByName(const char* pszName) override;
-        virtual OGRLayer   *ExecuteSQL( const char *pszSQLCommand,
-                                        OGRGeometry *poSpatialFilter,
-                                        const char *pszDialect ) override;
-        virtual void        ReleaseResultSet( OGRLayer * poLayer ) override;
-
-        json_object        *RunRequest(const char* pszURL,
-                                       int bQuiet404Error = FALSE);
-
-        static GDALDataset* Open(GDALOpenInfo* poOpenInfo);
-};
-
-class OGRPLScenesLayer: public OGRLayer
-{
-            friend class OGRPLScenesDataset;
-
-            OGRPLScenesDataset* poDS;
-            CPLString       osBaseURL;
-            OGRFeatureDefn* poFeatureDefn;
-            OGRSpatialReference* poSRS;
-            bool            bEOF;
-            GIntBig         nNextFID;
-            GIntBig         nFeatureCount;
-            CPLString       osNextURL;
-            CPLString       osRequestURL;
-            CPLString       osQuery;
-
-            OGRGeoJSONDataSource *poGeoJSONDS;
-            OGRLayer             *poGeoJSONLayer;
-
-            OGRGeometry    *poMainFilter;
-
-            int             nPageSize;
-            bool            bStillInFirstPage;
-            int             bAcquiredAscending;
-
-            bool            bFilterMustBeClientSideEvaluated;
-            CPLString       osFilterURLPart;
-
-            OGRFeature     *GetNextRawFeature();
-            CPLString       BuildURL(int nFeatures);
-            int             GetNextPage();
-            CPLString       BuildFilter(swq_expr_node* poNode);
-
-    public:
-                            OGRPLScenesLayer(OGRPLScenesDataset* poDS,
-                                             const char* pszName,
-                                             const char* pszBaseURL,
-                                             json_object* poObjCount10 = NULL);
-                           virtual ~OGRPLScenesLayer();
-
-        virtual void            ResetReading() override;
-        virtual GIntBig         GetFeatureCount(int bForce = FALSE) override;
-        virtual OGRFeature     *GetNextFeature() override;
-        virtual int             TestCapability(const char*) override;
-        virtual OGRFeatureDefn *GetLayerDefn() override { return poFeatureDefn; }
-
-        virtual void        SetSpatialFilter( OGRGeometry *poGeom ) override;
-        virtual void        SetSpatialFilter( int iGeomField, OGRGeometry *poGeom ) override
-                { OGRLayer::SetSpatialFilter(iGeomField, poGeom); }
-
-        virtual OGRErr      SetAttributeFilter( const char * ) override;
-
-        virtual OGRErr      GetExtent( OGREnvelope *psExtent, int bForce ) override;
-        virtual OGRErr      GetExtent(int iGeomField, OGREnvelope *psExtent, int bForce) override
-                { return OGRLayer::GetExtent(iGeomField, psExtent, bForce); }
-
-        void                SetMainFilterRect(double dfMinX, double dfMinY,
-                                              double dfMaxX, double dfMaxY);
-        void                SetAcquiredOrderingFlag(int bAcquiredAscendingIn)
-                                { bAcquiredAscending = bAcquiredAscendingIn; }
-};
-
 class OGRPLScenesV1Layer;
 class OGRPLScenesV1Dataset: public GDALDataset
 {
