@@ -33,7 +33,7 @@
 #include "ogrpgeogeometry.h"
 #include <string>
 
-CPL_CVSID("$Id: ogrvrtlayer.cpp 37371 2017-02-13 11:41:59Z rouault $");
+CPL_CVSID("$Id: ogrvrtlayer.cpp 39817 2017-08-14 15:47:46Z rouault $");
 
 #define UNSUPPORTED_OP_READ_ONLY "%s : unsupported operation on a read-only datasource."
 
@@ -1119,7 +1119,11 @@ error:
     CPLFree( pszSrcDSName );
     poFeatureDefn->Release();
     poFeatureDefn = new OGRFeatureDefn( osName );
+    poFeatureDefn->SetGeomType(wkbNone);
     poFeatureDefn->Reference();
+    for( size_t i = 0; i < apoGeomFieldProps.size(); i++ )
+        delete apoGeomFieldProps[i];
+    apoGeomFieldProps.clear();
     return false;
 }
 
